==> lms-1.6.1+libs.tar.gz: lms/modules/netdevdel.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netdevdel.php,v 1.15.2.2 2005/05/20 11:44:40 kondi Exp $
 */

if(! $LMS->NetDevExists($_GET['id']))
{
	$SESSION->redirect('?m=netdevlist');
}		

$layout['pagetitle'] = trans('Deletion of Device with ID: $0',sprintf('%04d',$_GET['id']));
$SMARTY->assign('netdevid',$_GET['id']);

if($LMS->CountNetDevLinks($_GET['id'])>0)
{
	$body = '<H1>'.$layout['pagetitle'].'</H1>';
	$body .= '<P>'.trans('Device connected to other device or node can\'t be deleted.').'</P>';
}else{
    if($_GET['is_sure']!=1)
    {
	    $body = '<H1>'.$layout['pagetitle'].'</H1>';
	    $body .= '<P>'.trans('Are you sure, you want to delete that device?').'</P>'; 
	    $body .= '<P><A HREF="?m=userdel&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I am sure.').'</A></P>';
    }else{
	    header('Location: ?m=netdevlist');
	    $body = '<H1>'.$layout['pagetitle'].'</H1>';
	    $body .= '<P>'.trans('Device has been deleted.').'</P>';
	    $LMS->DeleteNetDev($_GET['id']);
    }
}
	

$SMARTY->display('header.html');
$SMARTY->assign('body',$body);
$SMARTY->display('dialog.html');
$SMARTY->display('footer.html');

?>

==> lms-1.7.4+libs.tar.gz: lms/modules/netdevdel.php <==
<?php

/*
 * LMS version 1.7.4 Wraith
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netdevdel.php,v 1.18 2005/05/26 11:33:03 alec Exp $
 */

if(! $LMS->NetDevExists($_GET['id']))
{
	$SESSION->redirect('?m=netdevlist');
}		

$layout['pagetitle'] = trans('Deletion of Device with ID: $0',sprintf('%04d',$_GET['id']));
$SMARTY->assign('netdevid',$_GET['id']);

if($LMS->CountNetDevLinks($_GET['id'])>0)
{
	$body = '<H1>'.$layout['pagetitle'].'</H1>';
	$body .= '<P>'.trans('Device connected to other device or node can\'t be deleted.').'</P>';
}else{
    if($_GET['is_sure']!=1)
    {
	    $body = '<H1>'.$layout['pagetitle'].'</H1>';
	    $body .= '<P>'.trans('Are you sure, you want to delete that device?').'</P>'; 
	    $body .= '<P><A HREF="?m=customerdel&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I am sure.').'</A></P>';
    }else{
	    header('Location: ?m=netdevlist');
	    $body = '<H1>'.$layout['pagetitle'].'</H1>';
	    $body .= '<P>'.trans('Device has been deleted.').'</P>';
	    $LMS->DeleteNetDev($_GET['id']);
    }
}
	

$SMARTY->display('header.html');
$SMARTY->assign('body',$body);
$SMARTY->display('dialog.html');
$SMARTY->display('footer.html');

?>
